@@ -12,8 +12,5 @@ pub use route::*;
 mod message;
 pub use message::*;
 
-mod services;
-pub use services::*;
-
 mod macros;
 pub use macros::*;
